@@ -143,7 +143,7 @@ def show_policies() -> None:
         return
     print("Found iam_info, good...")
     print("found [{}]".format(metadata.iam_info))
-    iam = boto3.client('iam')
+    iam = boto3.client('iam', region_name=metadata.region)
     instance_profile_arn = metadata.iam_info["InstanceProfileArn"]
     print("instance_profile_arn [{}]".format(instance_profile_arn))
     name = instance_profile_arn.split("/")[1]
